# SpotiStats

A simple command line application used for interacting with the Spotify api. Currently it can search for songs, artists, and tracks on Spotify.

# Todo

- [ ] Reconfigure project to instead being an installable package that is used in a CLI tool
- [ ] Configure installation for pypi
- [ ] Add to PATH when installed
